#
# spec file for package python-certstream
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-certstream
Version:        1.12
Release:        3.1
Summary:        Python library for receiving certificate transparency list updates
License:        MIT
URL:            https://github.com/CaliDog/certstream-python/
Source0:        https://files.pythonhosted.org/packages/source/c/certstream/certstream-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 18.0.1}
BuildRequires:  %{python_module wheel}
#SECTION tests
BuildRequires:  %{python_module termcolor}
BuildRequires:  %{python_module websocket-client >= 0.58.0}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
# /SECTION
Requires:       python3-termcolor
Requires:       python3-websocket-client >= 0.48.0
BuildArch:      noarch

%python_subpackages

%description
Certstream is a library to connect to the certstream network (certstream.calidog.io).

It supports automatic reconnection when networks issues occur, and should be stable for long-running jobs.

%prep
%autosetup -p1 -n certstream-%{version}
# do not hardcode dependencies
sed -i -e 's:==:>=:g' requirements.txt

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/certstream
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# there are no tests

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative certstream

# post and postun macro call is not needed with only libalternatives

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/certstream/
%{python_sitelib}/certstream-%{version}*-info
%python_alternative %{_bindir}/certstream

%changelog
* Wed Jun  4 2025 Nico Krapp <nico.krapp@suse.com>
- fix usage of libalternatives
* Thu May 15 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Apr 29 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.12:
  - update to and require websocket-client>=0.58.0
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.11.0:
  - adding url to examples
  - Switched to using a module-specific logger so code calling this module can have better control over logs.
  - Update websocket-client and add ping every 15s
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary (rpmlint).
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10:
  * no upstream changelog
- Drop merged add-license.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Feb 28 2018 sebix+novell.com@sebix.at
- update to version 1.9
  * support for arbitrary kwargs
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- add add-license.patch to add LICENSE file
* Sat Dec  2 2017 sebix+novell.com@sebix.at
- initial package for version 1.8
